/* File: ctrl_controller_test.h; Copyright and License: see below */

#ifndef CTRL_CONTROLLER_TEST_H
#define CTRL_CONTROLLER_TEST_H

/*!
 *  \file
 *  \brief MODULE TEST for data_database, ctrl_controller,
 *  focussing on opening, switching and closing files
 */

#include "test_suite.h"

test_suite_t ctrl_controller_test_get_list(void);

#endif  /* CTRL_CONTROLLER_TEST_H */


/*
 * Copyright 2018-2021 Andreas Warnke
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
